==> huaweicloudsdkcce-3.1.134-py2.py3-none-any.whl: huaweicloudsdkcce/v3/model/node_template_runtime_config.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class NodeTemplateRuntimeConfig:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'runtime': 'NodeTemplateRuntimeConfigRuntime'
    }

    attribute_map = {
        'runtime': 'runtime'
    }

    def __init__(self, runtime=None):
        """NodeTemplateRuntimeConfig

        The model defined in huaweicloud sdk

        :param runtime: 
        :type runtime: :class:`huaweicloudsdkcce.v3.NodeTemplateRuntimeConfigRuntime`
        """
        
        

        self._runtime = None
        self.discriminator = None

        if runtime is not None:
            self.runtime = runtime

    @property
    def runtime(self):
        """Gets the runtime of this NodeTemplateRuntimeConfig.

        :return: The runtime of this NodeTemplateRuntimeConfig.
        :rtype: :class:`huaweicloudsdkcce.v3.NodeTemplateRuntimeConfigRuntime`
        """
        return self._runtime

    @runtime.setter
    def runtime(self, runtime):
        """Sets the runtime of this NodeTemplateRuntimeConfig.

        :param runtime: The runtime of this NodeTemplateRuntimeConfig.
        :type runtime: :class:`huaweicloudsdkcce.v3.NodeTemplateRuntimeConfigRuntime`
        """
        self._runtime = runtime

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NodeTemplateRuntimeConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcce-3.1.151-py2.py3-none-any.whl: huaweicloudsdkcce/v3/model/node_template_runtime_config.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class NodeTemplateRuntimeConfig:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'runtime': 'NodeTemplateRuntimeConfigRuntime'
    }

    attribute_map = {
        'runtime': 'runtime'
    }

    def __init__(self, runtime=None):
        r"""NodeTemplateRuntimeConfig

        The model defined in huaweicloud sdk

        :param runtime: 
        :type runtime: :class:`huaweicloudsdkcce.v3.NodeTemplateRuntimeConfigRuntime`
        """
        
        

        self._runtime = None
        self.discriminator = None

        if runtime is not None:
            self.runtime = runtime

    @property
    def runtime(self):
        r"""Gets the runtime of this NodeTemplateRuntimeConfig.

        :return: The runtime of this NodeTemplateRuntimeConfig.
        :rtype: :class:`huaweicloudsdkcce.v3.NodeTemplateRuntimeConfigRuntime`
        """
        return self._runtime

    @runtime.setter
    def runtime(self, runtime):
        r"""Sets the runtime of this NodeTemplateRuntimeConfig.

        :param runtime: The runtime of this NodeTemplateRuntimeConfig.
        :type runtime: :class:`huaweicloudsdkcce.v3.NodeTemplateRuntimeConfigRuntime`
        """
        self._runtime = runtime

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NodeTemplateRuntimeConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
